@@ -301,3 +301,46 @@ class I32:
         frozenbitarray("1110011"): ENVIRONMENT.__func__,
         frozenbitarray("0001111"): FENCE.__func__,
     }
+
+    instructionNameSet = {
+        "lui",
+        "auipc",
+        "jal",
+        "jalr",
+        "beq",
+        "bne",
+        "blt",
+        "bge",
+        "bltu",
+        "bgeu",
+        "lb",
+        "lh",
+        "lw",
+        "lbu",
+        "lhu",
+        "sb",
+        "sh",
+        "sw",
+        "addi",
+        "slti",
+        "sltiu",
+        "xori",
+        "ori",
+        "andi",
+        "slli",
+        "srli",
+        "srai",
+        "add",
+        "sub",
+        "sll",
+        "slt",
+        "sltu",
+        "xor",
+        "srl",
+        "sra",
+        "or",
+        "and",
+        "ecall",
+        "ebreak",
+        "fence",
+    }
