@@ -1,5 +1,5 @@
 """ A RISC-V New Instruction Recommender System """
-__version__ = "0.3.0"
+__version__ = "0.5.0"
 
 from .RVFormatParser import RVFormatParser
 from .RVInstruction import RVInstruction
@@ -9,5 +9,7 @@ from .I32 import I32
 from .M32 import M32
 from .V32 import V32
 from .RV32 import RV32
+from .Histogram import Histogram
 
 from .main import main
+from .unused import unused
